@@ -68,7 +68,7 @@ test_that("working examples", {
     numberIndividuals = 2
   )
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(tableName = "cohort2", value = "date", nameStyle = "xx")
 
   expect_true(length(attributes(cdm$cohort1)) == length(attributes(result)))
@@ -84,7 +84,7 @@ test_that("working examples", {
     }
   }
 
-  result <- result %>%
+  result <- result |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -93,12 +93,12 @@ test_that("working examples", {
   expect_true(colnames(result)[3] == "cohort_start_date")
   expect_true(colnames(result)[4] == "cohort_end_date")
 
-  expect_true(all(result %>% dplyr::pull("xx") == as.Date(c("2020-01-15", "2020-01-15", "2020-01-25", "2020-01-24", "2020-03-15"))))
+  expect_true(all(result |> dplyr::pull("xx") == as.Date(c("2020-01-15", "2020-01-15", "2020-01-25", "2020-01-24", "2020-03-15"))))
 
-  result1 <- cdm$cohort1 %>%
-    .addIntersect(tableName = "cohort2", value = "count") %>%
-    .addIntersect(tableName = "cohort2", value = "days") %>%
-    .addIntersect(tableName = "cohort2", value = "flag") %>%
+  result1 <- cdm$cohort1 |>
+    .addIntersect(tableName = "cohort2", value = "count") |>
+    .addIntersect(tableName = "cohort2", value = "days") |>
+    .addIntersect(tableName = "cohort2", value = "flag") |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -107,17 +107,17 @@ test_that("working examples", {
   expect_true(all(result1$flag_all_0_to_inf == c(1, 1, 1, 1, 1)))
 
   result2 <-
-    cdm$cohort1 %>%
-    .addIntersect(tableName = "cohort2", value = "count", order = "last") %>%
-    .addIntersect(tableName = "cohort2", value = "flag", order = "last") %>%
-    .addIntersect(tableName = "cohort2", value = "date", order = "last") %>%
-    .addIntersect(tableName = "cohort2", value = "days", order = "last") %>%
+    cdm$cohort1 |>
+    .addIntersect(tableName = "cohort2", value = "count", order = "last") |>
+    .addIntersect(tableName = "cohort2", value = "flag", order = "last") |>
+    .addIntersect(tableName = "cohort2", value = "date", order = "last") |>
+    .addIntersect(tableName = "cohort2", value = "days", order = "last") |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
   result6 <-
-    cdm$cohort1 %>%
-    .addIntersect(tableName = "cohort2", value = c("date", "count", "days", "flag"), order = "last") %>%
+    cdm$cohort1 |>
+    .addIntersect(tableName = "cohort2", value = c("date", "count", "days", "flag"), order = "last") |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -133,23 +133,23 @@ test_that("working examples", {
   expect_true(all(result2$flag_all_0_to_inf == c(1, 1, 1, 1, 1)))
 
   result3 <-
-    cdm$cohort1 %>%
+    cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-Inf, 0)), value = "date"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-Inf, 0)), value = "days"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-Inf, 0)), value = "count"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-Inf, 0)), value = "flag"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -160,19 +160,19 @@ test_that("working examples", {
   expect_true(all(result3$count_all_minf_to_0 == c(0, 1, 1, 0, 2)))
   expect_true(all(result3$flag_all_minf_to_0 == c(0, 1, 1, 0, 1)))
 
-  result4 <- cdm$cohort1 %>%
+  result4 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", window = list(c(-30, 30)), value = "date"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2", window = list(c(-30, 30)), value = "days"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2", window = list(c(-30, 30)), value = "count"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2", window = list(c(-30, 30)), value = "flag"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -183,32 +183,32 @@ test_that("working examples", {
   expect_true(all(result4$count_all_m30_to_30 == c(3, 3, 4, 2, 2)))
   expect_true(all(result4$flag_all_m30_to_30 == c(1, 1, 1, 1, 1)))
 
-  result5 <- cdm$cohort1 %>%
+  result5 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-30, 30)),
       value = "date",
       order = "last"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-30, 30)),
       value = "days",
       order = "last"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-30, 30)),
       value = "count",
       order = "last"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2",
       window = list(c(-30, 30)),
       value = "flag",
       order = "last"
-    ) %>%
-    dplyr::arrange(subject_id, cohort_start_date) %>%
+    ) |>
+    dplyr::arrange(subject_id, cohort_start_date) |>
     dplyr::collect()
 
 
@@ -257,10 +257,10 @@ test_that("working examples with cohort_end_date", {
     numberIndividuals = 2
   )
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", value = "date", indexDate = "cohort_end_date"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -308,15 +308,15 @@ test_that("working examples with extra column", {
     numberIndividuals = 2
   )
 
-  cdm$cohort2 <- cdm$cohort2 %>%
+  cdm$cohort2 <- cdm$cohort2 |>
     dbplyr::window_order(
       .data$cohort_definition_id, .data$subject_id, .data$cohort_start_date
-    ) %>%
-    dplyr::mutate(measurment_result = dplyr::row_number()) %>%
-    dbplyr::window_order() %>%
+    ) |>
+    dplyr::mutate(measurment_result = dplyr::row_number()) |>
+    dbplyr::window_order() |>
     dplyr::compute()
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       value = c("flag", "measurment_result"),
@@ -324,11 +324,11 @@ test_that("working examples with extra column", {
       filterId = 1,
       idName = "covid",
       window = list(c(0, Inf))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
-  result1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       value = "measurment_result",
@@ -336,7 +336,7 @@ test_that("working examples with extra column", {
       filterId = 2,
       idName = "covid",
       window = list(c(0, Inf))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -361,28 +361,28 @@ test_that("working examples with extra column", {
     numberIndividuals = 2
   )
 
-  cdm$cohort2 <- cdm$cohort2 %>%
+  cdm$cohort2 <- cdm$cohort2 |>
     dbplyr::window_order(
       .data$cohort_definition_id, .data$subject_id, .data$cohort_start_date
-    ) %>%
-    dplyr::mutate(measurment_result = dplyr::row_number()) %>%
-    dbplyr::window_order() %>%
+    ) |>
+    dplyr::mutate(measurment_result = dplyr::row_number()) |>
+    dbplyr::window_order() |>
     dplyr::compute()
 
-  result2 <- cdm$cohort1 %>%
+  result2 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", value = "measurment_result",
       nameStyle = "{value}_{window_name}"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
-  result3 <- cdm$cohort1 %>%
+  result3 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", value = c("flag", "measurment_result"),
       nameStyle = "{value}_{window_name}",
       window = list(c(-400, -200))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -435,11 +435,11 @@ test_that("working examples with multiple cohort Ids", {
     return(same)
   }
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = 1, value = "date"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -447,37 +447,37 @@ test_that("working examples with multiple cohort Ids", {
     "2020-01-15", "2020-01-15", "2020-01-25", NA, NA
   )))))
 
-  result1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = 2, value = "count"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
   expect_true(all(result1$count_id2_0_to_inf == c(1, 1, 1, 1, 0)))
 
-  result2 <- cdm$cohort1 %>%
+  result2 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = c(1, 3), value = "flag"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = c(1, 3), value = "count"
-    ) %>%
+    ) |>
     .addIntersect(
       tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = c(1, 3), value = "days"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
-  result3 <- cdm$cohort1 %>%
+  result3 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", filterVariable = "cohort_definition_id",
       filterId = c(1, 3), value = c("count", "days", "flag")
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -528,23 +528,23 @@ test_that("working examples calculating as incidence target cohort", {
     return(same)
   }
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       window = c(-Inf, Inf),
       value = "date",
       nameStyle = "test_{id_name}_{window_name}"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
-  result1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       window = c(-Inf, Inf),
       value = "date",
       targetEndDate = NULL
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -595,20 +595,20 @@ test_that("working examples with more than one window", {
     return(same)
   }
 
-  result <- cdm$cohort1 %>%
-    .addIntersect(tableName = "cohort2", value = "date") %>%
+  result <- cdm$cohort1 |>
+    .addIntersect(tableName = "cohort2", value = "date") |>
     .addIntersect(
       tableName = "cohort2", value = "date", window = list(c(-Inf, 0))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
-  result1 <- cdm$cohort1 %>%
+  result1 <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       value = "date",
       window = list(c(0, Inf), c(-Inf, 0))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -701,25 +701,25 @@ test_that("working examples with tables, not cohorts", {
     return(same)
   }
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(
       tableName = "condition_occurrence", value = "date",
       targetStartDate = "condition_start_date",
       targetEndDate = "condition_end_date",
       window = list(c(0, Inf), c(-Inf, 0))
-    ) %>%
+    ) |>
     dplyr::collect()
 
   expect_true(all(result$date_all_0_to_inf %in% as.Date(c("2020-01-15", "2020-01-15", "2020-01-25", "2020-01-24", "2020-03-15"))))
 
-  result1 <- cdm$condition_occurrence %>%
+  result1 <- cdm$condition_occurrence |>
     .addIntersect(
       tableName = "drug_exposure", value = "count",
       indexDate = "condition_start_date",
       targetStartDate = "drug_exposure_start_date", targetEndDate = NULL,
       window = list(c(0, Inf), c(-Inf, 0)), filterVariable = "drug_concept_id",
       filterId = c(1, 2)
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(person_id, condition_start_date)
 
@@ -729,40 +729,40 @@ test_that("working examples with tables, not cohorts", {
   expect_true(all(result1$count_id1_minf_to_0 == c(0, 0, 0, 1, 0, 0, 0)))
   expect_true(all(result1$count_id2_minf_to_0 == c(1, 1, 1, 1, 0, 0, 0)))
 
-  result2 <- cdm$condition_occurrence %>%
+  result2 <- cdm$condition_occurrence |>
     .addIntersect(
       tableName = "drug_exposure", value = "count",
       indexDate = "condition_start_date",
       targetStartDate = "drug_exposure_start_date", targetEndDate = NULL,
       window = list(c(0, Inf), c(-Inf, 0))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(person_id, condition_start_date)
 
   expect_true(all(result1$count_id1_0_to_inf + result1$count_id2_0_to_inf == result2$count_all_0_to_inf))
   expect_true(all(result1$count_id1_minf_to_0 + result1$count_id2_minf_to_0 == result2$count_all_minf_to_0))
 
-  result3 <- cdm$condition_occurrence %>%
+  result3 <- cdm$condition_occurrence |>
     .addIntersect(
       tableName = "drug_exposure", value = "date",
       indexDate = "condition_start_date",
       targetStartDate = "drug_exposure_start_date", targetEndDate = NULL,
       window = list(c(0, Inf)), filterVariable = "drug_concept_id",
       filterId = c(1, 2)
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(person_id, condition_start_date)
   # test output all zero column when no result found
   expect_true(all(is.na(result3$date_id2_0_to_inf)))
 
-  result4 <- cdm$condition_occurrence %>%
+  result4 <- cdm$condition_occurrence |>
     .addIntersect(
       tableName = "drug_exposure", value = "days",
       indexDate = "condition_start_date",
       targetStartDate = "drug_exposure_start_date", targetEndDate = NULL,
       window = list(c(0, Inf)), filterVariable = "drug_concept_id",
       filterId = c(1, 2)
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(person_id, condition_start_date)
   # test output all zero column when no result found
@@ -856,7 +856,7 @@ test_that("test checkWindow function", {
   skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
 
-  expect_error(cdm$cohort1 %>%
+  expect_error(cdm$cohort1 |>
     .addIntersect(
       value = "days",
       filterId = 1,
@@ -900,37 +900,37 @@ test_that("test if column exist, overwrite", {
   )
 
   expect_message(
-    result <- cdm$cohort1 %>%
+    result <- cdm$cohort1 |>
       .addIntersect(
         tableName = "cohort2",
         value = c("flag", "date", "days", "count"), window = list(c(0, 30))
-      ) %>%
+      ) |>
       dplyr::collect()
   )
 
   expect_true(sum(colnames(result) == "flag_all_0_to_30") == 1)
-  expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
+  expect_true(all(result |> dplyr::arrange(cohort_start_date, subject_id) |>
     dplyr::select(flag_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
+    cohort1 |>
+      dplyr::arrange(cohort_start_date, subject_id) |>
       dplyr::select(flag_all_0_to_30), na.rm = TRUE))
 
-  expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
+  expect_true(all(result |> dplyr::arrange(cohort_start_date, subject_id) |>
     dplyr::select(count_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
+    cohort1 |>
+      dplyr::arrange(cohort_start_date, subject_id) |>
       dplyr::select(count_all_0_to_30), na.rm = TRUE))
 
-  expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
+  expect_true(all(result |> dplyr::arrange(cohort_start_date, subject_id) |>
     dplyr::select(days_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
+    cohort1 |>
+      dplyr::arrange(cohort_start_date, subject_id) |>
       dplyr::select(days_all_0_to_30), na.rm = TRUE))
 
-  expect_true(all(result %>% dplyr::arrange(cohort_start_date, subject_id) %>%
+  expect_true(all(result |> dplyr::arrange(cohort_start_date, subject_id) |>
     dplyr::select(date_all_0_to_30) !=
-    cohort1 %>%
-      dplyr::arrange(cohort_start_date, subject_id) %>%
+    cohort1 |>
+      dplyr::arrange(cohort_start_date, subject_id) |>
       dplyr::select(date_all_0_to_30), na.rm = TRUE))
 
   mockDisconnect(cdm = cdm)
@@ -998,12 +998,12 @@ test_that("overlapTable is empty, check return columns", {
   )
 
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2", value = c("date", "days", "count", "flag"),
       filterVariable = "cohort_definition_id",
       filterId = 2
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -1092,10 +1092,10 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
     return(same)
   }
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     addCohortIntersectCount(
       targetCohortTable = "cohort2"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -1103,10 +1103,10 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
 
   expect_true(all(result$cohort_1_0_to_inf == 0))
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     addCohortIntersectFlag(
       targetCohortTable = "cohort2"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -1114,10 +1114,10 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
 
   expect_true(all(result$cohort_1_0_to_inf == 0))
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     addCohortIntersectDate(
       targetCohortTable = "cohort2"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -1125,10 +1125,10 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
 
   expect_true(all(is.na(result$cohort_1_0_to_inf)))
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     addCohortIntersectDays(
       targetCohortTable = "cohort2"
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -1136,7 +1136,7 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
 
   expect_true(all(is.na(result$cohort_1_0_to_inf)))
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     .addIntersect(
       tableName = "cohort2",
       value = c("flag", "date"),
@@ -1144,7 +1144,7 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
       filterId = c(1, 2, 3),
       window = list(c(0, Inf), c(-30, -1)),
       idName = c("num1", "num2", "num3")
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -1171,21 +1171,21 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
   expect_true(all(is.na(result$date_num2_m30_to_m1)))
   expect_true(all(is.na(result$date_num1_m30_to_m1)))
 
-  expect_error(cdm$cohort1 %>%
+  expect_error(cdm$cohort1 |>
     addCohortIntersectDate(
       targetCohortTable = "cohort2",
       targetCohortId = c(1, 2, 3),
       window = list(c(0, Inf), c(-30, -1))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date))
 
-  result <- cdm$cohort1 %>%
+  result <- cdm$cohort1 |>
     addCohortIntersectDate(
       targetCohortTable = "cohort2",
       targetCohortId = c(1, 3),
       window = list(c(0, Inf), c(-30, -1))
-    ) %>%
+    ) |>
     dplyr::collect() |>
     dplyr::arrange(subject_id, cohort_start_date)
 
@@ -1207,8 +1207,8 @@ test_that("overlap is empty or not, multiple ids, check return columns", {
 test_that("non snake columns not repeated in output", {
   skip_on_cran()
   cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
-  attr(cdm$cohort1, "cohort_set") <- attr(cdm$cohort1, "cohort_set") %>% dplyr::mutate(cohort_name = toupper(cohort_name))
-  cdm$cohort2 <- cdm$cohort2 %>%
+  attr(cdm$cohort1, "cohort_set") <- attr(cdm$cohort1, "cohort_set") |> dplyr::mutate(cohort_name = toupper(cohort_name))
+  cdm$cohort2 <- cdm$cohort2 |>
     addCohortIntersectFlag(targetCohortTable = "cohort1")
 
   expect_true("cohort_1_0_to_inf" %in% colnames(cdm$cohort2))
@@ -1224,7 +1224,7 @@ test_that("no NA when overwrite column", {
   )
 
   # Presence in characteristis 'cohort 1' in 180 days before cohort start
-  cdm$cohort1 <- cdm$cohort1 %>%
+  cdm$cohort1 <- cdm$cohort1 |>
     addCohortIntersectFlag(
       targetCohortTable = "cohort2",
       window = list(c(-180, -1)),
@@ -1235,7 +1235,7 @@ test_that("no NA when overwrite column", {
 
   # Trying to overwrite the previous created variable, for example because the characteristics cohort has changed.
   expect_message(
-    cdm$cohort1 <- cdm$cohort1 %>%
+    cdm$cohort1 <- cdm$cohort1 |>
       addCohortIntersectFlag(
         targetCohortTable = "cohort2",
         window = list(c(-180, -1)),
@@ -1244,16 +1244,16 @@ test_that("no NA when overwrite column", {
       )
   )
 
-  expect_true(!any(is.na(cdm$cohort1 %>% dplyr::pull("cohort_1"))))
+  expect_true(!any(is.na(cdm$cohort1 |> dplyr::pull("cohort_1"))))
 
   # subject 2, who has no record for cohort_definition_id 1 in the characteristics cohort, now gets a "NA"
 
   # Moving the "cohort_definition_id == 1" records from subject 1 to subject 2:
-  cdm$cohort2 <- cdm$cohort2 %>%
+  cdm$cohort2 <- cdm$cohort2 |>
     dplyr::mutate(subject_id = dplyr::if_else(cohort_definition_id == 1 & subject_id == 1, 2, subject_id))
 
   expect_message(
-    cdm$cohort1 <- cdm$cohort1 %>%
+    cdm$cohort1 <- cdm$cohort1 |>
       addCohortIntersectFlag(
         targetCohortTable = "cohort2",
         window = list(c(-180, -1)),
@@ -1262,7 +1262,7 @@ test_that("no NA when overwrite column", {
       )
   )
 
-  expect_true(!any(is.na(cdm$cohort1 %>% dplyr::pull("cohort_1"))))
+  expect_true(!any(is.na(cdm$cohort1 |> dplyr::pull("cohort_1"))))
 
   mockDisconnect(cdm = cdm)
 })
